Struct SharedPollingSignals

pub struct SharedPollingSignals { /* private fields */ }
A filesystem path based way to poll for ‘signals’. When receiving a signal, it has to be confirmed explicitly, and the confirmation is shared amongst all readers (usable for “work was done” on a ‘versioned’ input; the work confirmed refers to the version of the signal that was read; the confirmation with the highest signal value is stored). Note that multiple readers might start doing the same work at the same time. Cloning shares the same receiver and sender.

Implementations

Source

impl SharedPollingSignals

pub fn open( channel_path: &Path, done_path: &Path, initial_value: u64, ) -> Result<Self, IPCAtomicError>

pub fn get_latest_signal(&self) -> Option<Signal<'_>>

If there were signals, returns a representation of the last one. confirm or ignore must be called on it when the action warranted by the signal has been carried out, dropping it will panic!

pub fn sender(&self) -> PollingSignalsSender