pub struct PollingSignals { /* private fields */ }Expand description
A filesystem path based way to poll for ‘signals’. Cloning makes another receiver that checks independently from the original (but both receive the same ‘signals’).
Implementations
Sourceimpl PollingSignals
impl PollingSignals
pub fn open(path: &Path, initial_value: u64) -> Result<Self, IPCAtomicError>
Sourcepub fn get_number_of_signals(&mut self) -> u64
pub fn get_number_of_signals(&mut self) -> u64
Check how many signals were received since the last check.
Sourcepub fn got_signals(&mut self) -> bool
pub fn got_signals(&mut self) -> bool
Check whether there were any signals (just
get_number_of_signals() > 0)
Sourcepub fn send_signal(&mut self) -> u64
pub fn send_signal(&mut self) -> u64
Send one signal. This is excluded from this PollingSignals
instance, i.e. get_number_of_signals() will not report
it. Returns the previous value.
pub fn sender(&self) -> PollingSignalsSender